# CLI Package

Authors: 
Cui Ding(olatname: cding)
Matriculation Numbers: 21-718-945
Mia Tatjana Egli (olatname: miaegl)
Matriculation Numbers: 21-700-406

This is a CLI package, using CLI to processing jokes. 

This is the exercise 3.